@@ -1,9 +1,11 @@
-package Dist::Zilla::Plugin::MetaYAML 6.015;
+package Dist::Zilla::Plugin::MetaYAML 6.033;
 # ABSTRACT: produce a META.yml
 
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
+use Dist::Zilla::Pragmas;
+
 use Try::Tiny;
 use namespace::autoclean;
 
@@ -101,7 +103,7 @@ Dist::Zilla::Plugin::MetaYAML - produce a META.yml
 
 =head1 VERSION
 
-version 6.015
+version 6.033
 
 =head1 DESCRIPTION
 
@@ -109,6 +111,19 @@ This plugin will add a F<META.yml> file to the distribution.
 
 For more information on this file, see L<Module::Build::API> and L<CPAN::Meta>.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 filename
@@ -131,11 +146,11 @@ L<CPAN::Meta::Spec>, L<YAML>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2025 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
